@@ -38,7 +38,7 @@ class StripJsdict(object):
         self.__dict__["_StripJsdict__f"] = form
     
     def __getattr__(self,name):
-        return self.__getitem__[name]
+        return self.__getitem__(name)
         
     def __getitem__(self,name):
         v = self.__f[name]
