@@ -52,6 +52,8 @@ def render_func(func):
 
         if type(r) is str:
             return r
+        elif r is False:
+            return ''
         else:
             return G(request=request)
 
