@@ -30,7 +30,7 @@ Luke Arno can be found at http://lukearno.com/
 
 import urllib
 import cgi
-import mimetypes
+#import mimetypes
 import Cookie
 from cStringIO import StringIO
 from dict_like import Jsdict
@@ -328,8 +328,8 @@ class Response(object):
         """Set up various useful defaults."""
         self._headers = []
         self.headers = headers.Headers(self._headers)
-        guess = mimetypes.guess_type(uri)[0]
-        self.headers['Content-Type'] = guess or 'text/html'
+        #guess = mimetypes.guess_type(uri)[0]
+        #self.headers['Content-Type'] = guess or 'text/html'
         self.status = '200 OK'
         self.body = ""
 
